@@ -33,10 +33,6 @@
 #include <QApplication>
 #endif
 
-#ifdef Q_OS_ANDROID
-Q_DECL_EXPORT
-#endif
-
 int main(int argc, char *argv[])
 {
 #ifdef Q_OS_ANDROID
@@ -80,14 +76,27 @@ int main(int argc, char *argv[])
     Fetcher::instance().fetchFavorites();
 
     // register qml types
-    qmlRegisterType<GroupsModel>("org.kde.TellySkout", 1, 0, "GroupsModel");
-    qmlRegisterType<ChannelsModel>("org.kde.TellySkout", 1, 0, "ChannelsModel");
-    qmlRegisterType<ChannelsProxyModel>("org.kde.TellySkout", 1, 0, "ChannelsProxyModel");
-    qmlRegisterType<ProgramsProxyModel>("org.kde.TellySkout", 1, 0, "ProgramsProxyModel");
-
-    qmlRegisterUncreatableType<ProgramsModel>("org.kde.TellySkout", 1, 0, "ProgramsModel", QStringLiteral("Get from Channel"));
-
-    qmlRegisterSingletonInstance("org.kde.TellySkout", 1, 0, "Fetcher", &Fetcher::instance());
+    qRegisterMetaType<ChannelId>();
+    QMetaType::registerConverter<ChannelId, QString>([](const ChannelId &channelId) {
+        return channelId.value();
+    });
+    QMetaType::registerConverter<QString, ChannelId>([](const QString &str) {
+        return ChannelId(str);
+    });
+    qRegisterMetaType<GroupId>();
+    QMetaType::registerConverter<GroupId, QString>([](const GroupId &groupId) {
+        return groupId.value();
+    });
+    QMetaType::registerConverter<QString, GroupId>([](const QString &str) {
+        return GroupId(str);
+    });
+    qRegisterMetaType<ProgramId>();
+    QMetaType::registerConverter<ProgramId, QString>([](const ProgramId &programId) {
+        return programId.value();
+    });
+    QMetaType::registerConverter<QString, ProgramId>([](const QString &str) {
+        return ProgramId(str);
+    });
 
     // setup engine
     QQmlApplicationEngine engine;
@@ -99,7 +108,7 @@ int main(int argc, char *argv[])
 
     QObject::connect(&app, &QCoreApplication::aboutToQuit, TellySkoutSettings::self(), &TellySkoutSettings::save);
 
-    engine.load(QUrl(QStringLiteral("qrc:///main.qml")));
+    engine.load(QUrl(QStringLiteral("qrc:/qml/main.qml")));
 
     if (engine.rootObjects().isEmpty()) {
         return -1;
