@@ -19,9 +19,9 @@ ProgramsModel::ProgramsModel(Channel *channel, ProgramFactory &programFactory)
     , m_programFactory(programFactory)
 {
     connect(&Fetcher::instance(), &Fetcher::channelUpdated, this, [this](const ChannelId &id) {
-        if (m_channel->id() == id.value()) {
+        if (m_channel->id() == id) {
             beginResetModel();
-            m_programFactory.load(ChannelId(m_channel->id()));
+            m_programFactory.load(m_channel->id());
             for (auto &&program : m_programs) {
                 delete program;
             }
@@ -29,6 +29,20 @@ ProgramsModel::ProgramsModel(Channel *channel, ProgramFactory &programFactory)
             endResetModel();
         }
     });
+
+    connect(&Fetcher::instance(), &Fetcher::programUpdated, this, [this](const ProgramId &id) {
+        beginResetModel();
+        for (int i = 0; i < m_programs.size(); ++i) {
+            const Program *program = m_programs[i];
+            if (id == program->id()) {
+                m_programFactory.load(program->channelId(), program->id());
+                delete program;
+                m_programs[i] = nullptr;
+                break;
+            }
+        }
+        endResetModel();
+    });
 }
 
 ProgramsModel::~ProgramsModel()
@@ -57,21 +71,27 @@ QHash<int, QByteArray> ProgramsModel::roleNames() const
 int ProgramsModel::rowCount(const QModelIndex &parent) const
 {
     Q_UNUSED(parent)
-    const ChannelId channelId(m_channel->id());
-    Q_ASSERT(m_programFactory.count(channelId) <= std::numeric_limits<int>::max());
-    return static_cast<int>(m_programFactory.count(channelId));
+    Q_ASSERT(m_programFactory.count(m_channel->id()) <= std::numeric_limits<int>::max());
+    return static_cast<int>(m_programFactory.count(m_channel->id()));
 }
 
 void ProgramsModel::loadProgram(int index) const
 {
-    Program *program = m_programFactory.create(ChannelId(m_channel->id()), index);
+    Program *program = m_programFactory.create(m_channel->id(), index);
 
     if (program) {
         // avoid gaps/overlapping in the program (causes not aligned times in table)
         if (m_programs.contains(index - 1) && m_programs[index - 1]->stop() != program->start()) {
             program->setStart(m_programs[index - 1]->stop());
         }
+        if (m_programs.contains(index)) {
+            delete m_programs[index];
+            m_programs[index] = nullptr;
+        }
         m_programs[index] = program;
+    } else {
+        delete program;
+        program = nullptr;
     }
 }
 
